operations

Function operations 

pub fn operations(manifest: &Manifest) -> Result<Vec<(String, String)>>
The set of (method, path) operations Gize generates for a module. Used both to build the spec and by the parity test that checks the spec against the router.